==> q3-ui-repeater-4.5.4.tgz: package/lib/components/ItemActions/ItemActions.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _TableCell = _interopRequireDefault(require("@material-ui/core/TableCell"));

var _IconButton = _interopRequireDefault(require("@material-ui/core/IconButton"));

var _KeyboardArrowUp = _interopRequireDefault(require("@material-ui/icons/KeyboardArrowUp"));

var _ItemActions = _interopRequireDefault(require("./ItemActions"));

var _ = require("..");

var _ItemActionsWrapper = _interopRequireDefault(require("../ItemActionsWrapper"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const baseProps = {
  parent: [{
    id: '1'
  }],
  index: 0,
  currentIndex: 0,
  toggleNested: jest.fn(),
  setCurrentIndex: jest.fn()
};
describe('ItemActions', () => {
  describe('"ItemActions"', () => {
    it('should return without children', () => {
      const el = global.shallow( /*#__PURE__*/_react.default.createElement(_ItemActions.default, _extends({}, baseProps, {
        showEditor: false,
        showRemove: false,
        nestedIsVisible: false
      }), /*#__PURE__*/_react.default.createElement("div", null))).find(_TableCell.default).children().length;
      expect(el).toBe(0);
    });
    it('should render IconButton toggle', () => {
      const el = global.shallow( /*#__PURE__*/_react.default.createElement(_ItemActions.default, _extends({}, baseProps, {
        showEditor: false,
        showRemove: false,
        renderNestedTableRow: jest.fn(),
        nestedIsVisible: true
      }), /*#__PURE__*/_react.default.createElement("div", null))).find(_IconButton.default);
      expect(el).toHaveLength(1);
      expect(el.find(_KeyboardArrowUp.default).exists()).toBeTruthy();
    });
    it('should render DeleteModal and EditorDrawer', () => {
      const el = global.shallow( /*#__PURE__*/_react.default.createElement(_ItemActions.default, _extends({}, baseProps, {
        showEditor: true,
        showRemove: true
      }), /*#__PURE__*/_react.default.createElement("div", null)));
      expect(el.find(_.DeleteModal).length).toBe(1);
      expect(el.find(_ItemActionsWrapper.default).length).toBe(1);
    });
  });
});

==> q3-ui-repeater-4.5.15.tgz: package/lib/components/ItemActions/ItemActions.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));
var _TableCell = _interopRequireDefault(require("@material-ui/core/TableCell"));
var _IconButton = _interopRequireDefault(require("@material-ui/core/IconButton"));
var _KeyboardArrowUp = _interopRequireDefault(require("@material-ui/icons/KeyboardArrowUp"));
var _ItemActions = _interopRequireDefault(require("./ItemActions"));
var _ = require("..");
var _ItemActionsWrapper = _interopRequireDefault(require("../ItemActionsWrapper"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const baseProps = {
  parent: [{
    id: '1'
  }],
  index: 0,
  currentIndex: 0,
  toggleNested: jest.fn(),
  setCurrentIndex: jest.fn()
};
describe('ItemActions', () => {
  describe('"ItemActions"', () => {
    it('should return without children', () => {
      const el = global.shallow( /*#__PURE__*/_react.default.createElement(_ItemActions.default, _extends({}, baseProps, {
        showEditor: false,
        showRemove: false,
        nestedIsVisible: false
      }), /*#__PURE__*/_react.default.createElement("div", null))).find(_TableCell.default).children().length;
      expect(el).toBe(0);
    });
    it('should render IconButton toggle', () => {
      const el = global.shallow( /*#__PURE__*/_react.default.createElement(_ItemActions.default, _extends({}, baseProps, {
        showEditor: false,
        showRemove: false,
        renderNestedTableRow: jest.fn(),
        nestedIsVisible: true
      }), /*#__PURE__*/_react.default.createElement("div", null))).find(_IconButton.default);
      expect(el).toHaveLength(1);
      expect(el.find(_KeyboardArrowUp.default).exists()).toBeTruthy();
    });
    it('should render DeleteModal and EditorDrawer', () => {
      const el = global.shallow( /*#__PURE__*/_react.default.createElement(_ItemActions.default, _extends({}, baseProps, {
        showEditor: true,
        showRemove: true
      }), /*#__PURE__*/_react.default.createElement("div", null)));
      expect(el.find(_.DeleteModal).length).toBe(1);
      expect(el.find(_ItemActionsWrapper.default).length).toBe(1);
    });
  });
});
